/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef LUAOUTPUT_H_
#define LUAOUTPUT_H_

extern "C" {
#include <lua.h>
#include <lualib.h>
#include <lauxlib.h>
}
#include "lua/LuaWrapper.h"
#include "lua/Luna.h"
#include "controller/LuaController.h"

/**
 * \class LuaOutput
 * \brief Wrapper class for the console.
 *
 * This class makes printing strings from Lua onto the console possible. The
 * output is transmitted via signals and slots. The signals are redirected by
 * LuaController, to make the use thread-safe.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 * \see LuaController
 */

class LuaOutput : public LuaWrapper
{
public:
    LuaOutput ( lua_State* );
    ~LuaOutput ();

    int print ( lua_State* );

    QObject * getController() const;
    /**
     * \brief Classname for Luna.
     *
     * \see Luna
     */
    static const char className[];
    /**
     * \brief Register of the functions.
     *
     * RegType for all methods, that will be used in Lua.
     */
    static const Luna<LuaOutput>::RegType Register[];



private:
    /**
     * \brief Object of the LuaController.
     */
    LuaController* controller_;

};

#endif /* LUAOUTPUT_H_ */
